/// <reference types="react" />

import type { Context } from 'react';
import { CSSProperties } from 'react';
import { DetailedHTMLProps } from 'react';
import { HTMLAttributes } from 'react';
import { Language as Language_2 } from 'prism-react-renderer';
import { ReactNode } from 'react';

export declare type ActualTheme = 'light' | 'dark';

export declare interface CodeFile {
    filename?: string;
    language: Language;
    code: string;
}

export declare function DocCodeBlock({ code, language, style }: DocCodeBlockProps): JSX.Element;

export declare interface DocCodeBlockProps {
    code: string;
    language: Language;
    style?: CSSProperties;
}

export declare function DocContainer({ maxWidth, style, ...props }: DocContainerProps): JSX.Element;

export declare interface DocContainerProps extends DetailedHTMLProps<HTMLAttributes<HTMLDivElement>, HTMLDivElement> {
    maxWidth?: number | string;
}

export declare const DocContext: Context<DocContextValue>;

export declare interface DocContextValue {
    theme: Theme;
    systemTheme: ActualTheme;
    actualTheme: ActualTheme;
    setTheme: (theme: Theme) => void;
}

export declare function DocDemoBlock({ children }: DocDemoBlockProps): JSX.Element;

export declare interface DocDemoBlockProps {
    children?: ReactNode;
}

export declare function DocHeader({ title }: DocHeaderProps): JSX.Element;

export declare interface DocHeaderProps {
    title?: ReactNode;
}

export declare function DocHeading({ level, children, style, ...props }: DocHeadingProps): JSX.Element;

export declare interface DocHeadingProps extends React.DetailedHTMLProps<React.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement> {
    level?: number;
}

export declare function DocProvider({ children }: DocProviderProps): JSX.Element;

export declare interface DocProviderProps {
    children?: ReactNode;
}

export declare function DocTabCodeBlock({ files }: DocTabCodeBlockProps): JSX.Element;

export declare interface DocTabCodeBlockProps {
    files: CodeFile[];
}

export declare type Language = LanguageAlias | Language_2;

declare type LanguageAlias = keyof typeof languageAliasDict;

declare const languageAliasDict: {
    cjs: string;
    cts: string;
    htm: string;
    html: string;
    js: string;
    md: string;
    mjs: string;
    mts: string;
    svg: string;
    ts: string;
    xml: string;
    yml: string;
};

export declare type Theme = 'auto' | 'light' | 'dark';

export declare function useDoc(): DocContextValue;

export { }
